import * as React from "react";
/**
 * A Table provides a useful abstraction for managing rows and columns.
 */
interface TableProps extends React.HTMLAttributes<HTMLTableElement> {
    /** An optional minimum width for table content.
     * 配置表格的最小宽度，小于它就启用水平滚动条。 举例：minWidth=css 单位。
     *  */
    minWidth?: string;
    /** An optional array of fixed layout widths for each column
     * 非打印场景的必须看fixed； 打印场景优先使用printColWidth；若这两者都没定义那就是系统自动的 走了浏览器默认机制。
     * 百分比% 和数值px两种形式。 举例：fixed={["8%","23%","%","12%"] }  printColWidth={["60","156","700","80"]}
     * */
    fixed?: string[];
    /**允许打印时刻特别调整各列的宽度比例
     * 就算不是百分比的配置 也即用pixels的：最后也是同义转换百分比处理
     * */
    printColWidth?: string[];
}
/**
 支持打印自适应，支持手机自适应。 Table不适合小屏幕和列数较多的字段长度不统一可能较长的这些情形。
 @param fixed:非打印的布局各列尺寸设置，一般是百分比比例。 若fixed不设置会自动调整的。
 @param printColWidth:真实打印或打印预览情况的布局各列尺寸，一般是px数值。合计一般：A4竖版就是合计718px，超过了会自动缩小字体。
 若printColWidth没必要一定要准确配置的呢？嵌套表格的上一级宽度已经是父辈Table做了约定的？
 @param agptWidth: 约定打印的合计总宽度，优先于printColWidth，打印各列宽度比例按照printColWidth比例映射，或者没有printColWidth就按照fixed比例映射；
  对于A4 竖版打印 windows chrome正好 718 px的不会缩小。
  嵌套在内部的表格 设置agptWidth={0} 可以自适应宽度；
 @param nested:嵌套表格，宽度被父辈Table做了约定的，并且要求自动和父辈同宽度的合并边线的。agptWidth若没有设置的就按比例分配100%宽度。
 文书正规视图的应该配置fixed或printColWidth，完全自适应也不友好：随数据长度变动各列位置可能不恰当！最好配置各列比例数。
 */
export declare const Table: React.FunctionComponent<TableProps>;
/**
 * A TableHead is used to render column labels in a table.
 */
interface TableHeadProps extends React.HTMLAttributes<HTMLTableSectionElement> {
    lrBoder?: boolean;
}
/**就算TableBody在DOM流位置比TableHead靠前，也TableHead表现一样；多个Table嵌套的打印断页拆分的也类似会有多个TableHead在页首部处留存。
 * */
export declare function TableHead({ lrBoder, children, ...other }: TableHeadProps): import("@emotion/react/jsx-runtime").JSX.Element;
interface TableRowProps extends React.HTMLAttributes<HTMLTableRowElement> {
    /** A callback when a row is selected */
    onClick?: () => void;
}
export declare const TableRow: React.FunctionComponent<TableRowProps>;
type AlignCellType = "right" | "left" | "center" | "justify";
type tableCellVariants = "head" | "body";
type TableCellBaseProps = React.ThHTMLAttributes<HTMLTableHeaderCellElement> & React.TdHTMLAttributes<HTMLTableDataCellElement>;
interface TableCellProps extends TableCellBaseProps {
    align?: AlignCellType;
    variant?: tableCellVariants;
    ellipsis?: boolean;
    component?: React.ElementType<TableCellBaseProps>;
    /**是否<td><th>在打印之中，遇到了分页位置应该允许断开。浏览器原先默认是断开的。这里改成默认不能拆分开的。
     * split=true就是允许打印拆分断开。
     * */
    split?: boolean;
}
/**
 * 旧版本的Cell组件，新版本改用Cell; 两个版本的样式不一样
 */
export declare const TableCell: React.FunctionComponent<TableCellProps>;
/**
 * 新版 TableCell 组件，支持手机上作表格形式的报告，支持打印。
 * 做报表用的样式, CCell, RCell类似 Cell,就差align格式;
 * 旧版本请用TableCell组件,两个版本的样式不一样
 * 前提：每一行的要么是td 要么是th，不要混合td和th;
 * @param split:允许打印拆分这个<td>吗？ component设置要注意 统一一行的td 要么th。
 */
export declare const Cell: React.FunctionComponent<TableCellProps>;
/**
 * TableBody - indicates the body (and scrollable) portion of our table.
 */
interface TableBodyProps extends React.HTMLAttributes<HTMLTableSectionElement> {
    lrBoder?: boolean;
}
export declare function TableBody({ lrBoder, children, ...other }: TableBodyProps): import("@emotion/react/jsx-runtime").JSX.Element;
/**
 * An ExpandingRow displays additional content about the row when clicked.
 */
interface ExpandingRowProps {
    /** The expanded content to show when the user selects the row */
    content: (close: () => void) => React.ReactNode | React.ReactNode;
    children: React.ReactNode;
}
export declare const ExpandingRow: React.FunctionComponent<ExpandingRowProps>;
/**
 大量重复的组件标签，简化: CCell代表居中显示的Cell
 */
export declare const CCell: React.FunctionComponent<TableCellProps>;
/**做点简化，免得看起来是一大堆重复性质代码：
 * 代表靠右边 显示的Cell
 */
export declare const RCell: React.FunctionComponent<TableCellProps>;
export {};
